@@ -1,8 +1,9 @@
-chkmiss <- function(x){
+chkmiss <- function(x, name=NULL){
   ##
   ## Check for missing values
   ##
-  name <- deparse(substitute(x))
+  if (is.null(name))
+    name <- deparse(substitute(x))
   ##
   if (any(is.na(x)))
     stop("Missing values in argument '", name, "'.",
