@@ -1,8 +1,9 @@
-chknull <- function(x){
+chknull <- function(x, name=NULL){
   ##
   ## Check whether argument is NULL
   ##
-  name <- deparse(substitute(x))
+  if (is.null(name))
+    name <- deparse(substitute(x))
   ##
   if (is.null(x))
     stop("Argument '", name, "' is NULL.", call.=FALSE)
