@@ -1,10 +1,16 @@
 print.rm5 <- function(x, ...){
   
-  if (!inherits(x, "rm5"))
-    stop("Argument 'x' must be an object of class \"rm5\"")
+  
+  ##
+  ##
+  ## (1) Check for rm5 object
+  ##
+  ##
+  chkclass(x, "rm5")
+  
   
   print.data.frame(x, ...)
   
+  
   invisible(NULL)
 }
-
